module.exports = {
    Game: null,
    // 游戏参数
    GameInfo: {
        score: 0,
        level: 0,
        state: 'none',

    },
    /** 重置游戏参数 */
    ResetData() {
        this.GameInfo.score = 0;
        this.GameInfo.level = 0;
        this.GameInfo.state = 'none';
    },
    // 音乐系统
    MusicSystem: {
        bg: true,
        click: true,
    },
    // 用户信息
    UserData: {

    },
    /**
     * 图片加载
     * @param {cc.Node} node 节点
     * @param {string} src 路径
     */
    loadImg(node, src) {
        let load_count = 0;
        /** 加载失败时，重复加载 直到次数为 3 */
        function load() {
            load_count += 1;
            cc.loader.loadRes(src, cc.SpriteFrame, (err, res) => {
                if (err) {
                    console.log('图片加载错误重复加载次数', load_count);
                    if (load_count < 3) load();
                } else {
                    node.getComponent(cc.Sprite).spriteFrame = res;
                }
            });
        }
        load();
    },
    /** 保存数据 */
    saveData() {
        window.localStorage.setItem('name', JSON.stringify(this.userData));
    },
    /** 获取数据 */ 
    fetchData() {
        let data = window.localStorage.getItem('name') ? JSON.parse(window.localStorage.getItem('name')) : null;
        return data;
    },
    /** 清除本地数据 */
    removeData() {
        window.localStorage.clear();
    },
}
function commonlyUse() {
    // 加载 or 预加载
    cc.director.loadScene('name');
    cc.director.preloadScene('name', () => console.log('预加载游戏场景成功'));
    
    // 获取游戏暂停状态
    cc.director.isPaused();

    // 暂停 or 开始
    cc.director.pause();
    cc.director.resume();

    // 颜色更换
    cc.hexToColor('#ffffff'); // 2.0 废弃
    new cc.Color({ r: 74, g: 172, b: 255 });

    // 图片加载
    cc.loader.loadRes(src, cc.SpriteFrame, (err, res) => {
        node.getComponent(cc.Sprite).spriteFrame = res;
    });
    
    // 加载网络图片（需要同源策略） src => { url: 'xxx', type: 'png' }
    cc.loader.load(src, (err, texture) => {
        node.getComponent(cc.Sprite).spriteFrame = new cc.SpriteFrame(texture);
    });

    // 检查两个节点是否重合
    node.getBoundingBoxToWorld().intersects(node.getBoundingBoxToWorld());

    // 把一个节点转换成世界坐标 从左下角开始算起，好像是这样
    node.convertToWorldSpaceAR(cc.v2(Anchor.x, Anchor.y));

    // 克隆
    cc.instantiate(node);

    // 定时器
    this.scheduleOnce(() => {

    }, 1);

    // 龙骨播放动画
    node.getComponent(dragonBones.ArmatureDisplay).playAnimation('name', 1); // 0 是无限循环

    //碰撞系统
    const MC = cc.director.getCollisionManager();
    MC.enabled = true;
    // 开启碰撞系统的调试线框绘制
    MC.enabledDebugDraw = true;
    MC.enabledDrawBoundingBox = true;

    // 物理系统
    const MP = cc.director.getPhysicsManager();
    MP.enabled = true;
    // 未知作用
    MP.enabledAccumulator = true; 
    // 开启物理系统的调试线框绘制
    MP.debugDrawFlags = cc.PhysicsManager.DrawBits.e_aabbBit | cc.PhysicsManager.DrawBits.e_pairBit | cc.PhysicsManager.DrawBits.e_centerOfMassBit | cc.PhysicsManager.DrawBits.e_jointBit | cc.PhysicsManager.DrawBits.e_shapeBit;
}